@@ -1,10 +1,8 @@
-import os
-
 from masonite.foundation import Application, Kernel
 from tests.integrations.config.providers import PROVIDERS
 from tests.integrations.Kernel import Kernel as AppKernel
 
-application = Application(os.getcwd())
+application = Application("tests/integrations/")
 
 """First Bind important providers needed to start the server
 """
